@@ -5,9 +5,8 @@
 #' @param method Which method to be used to estimate the spot-drift. Currently, three methods are available, 
 #' rolling mean and median as well as the kernel method of Christensen et al. (2018).
 #' The kernel is a left hand exponential kernel that will weigh newer observations more heavily than older observations.
-#' @param alignBy What time-frame should the estimator be applied? Accepted inputs are \code{"milliseconds"}, \code{"seconds"} and \code{"secs"} for seconds,
-#'  \code{"minutes"} and \code{"mins"} for minutes, and \code{"hours"} for hours.
-#' Standard is minutes
+#' @param alignBy character, indicating the time scale in which \code{alignPeriod} is expressed. 
+#' Possible values are: \code{"ticks"}, \code{"secs"}, \code{"seconds"}, \code{"mins"}, \code{"minutes"}, \code{"hours"}
 #' @param alignPeriod How often should the estimation take place? If \code{alignPeriod} is 5 the estimation will be done every fifth unit of \code{alignBy}.
 #' @param marketOpen Opening time of the market, standard is "09:30:00".
 #' @param marketClose Closing time of the market, standard is "16:00:00".
@@ -184,10 +183,10 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' parameters \code{alignBy} and \code{alignPeriod}.
 #'
 #' @param method specifies which method will be used to estimate the spot
-#' volatility. Options include \code{"detPer"} and \code{"stochper"}.
-#' See `Details'.
-#' @param alignBy string indicating the time scale in which \code{alignPeriod} is expressed.
-#' Possible values are: \code{"secs", "seconds", "mins", "minutes", "hours"}.
+#' volatility. Valid options are \code{"detPer"}, \code{"stochPer"} \code{"kernel"} \code{"piecewise"} \code{"garch"}, \code{"RM"} ,\code{"PARM"}
+#' See `Details' below for explanation and parameters to use in each of the methods.
+#' @param alignBy character, indicating the time scale in which \code{alignPeriod} is expressed. 
+#' Possible values are: \code{"ticks"}, \code{"secs"}, \code{"seconds"}, \code{"mins"}, \code{"minutes"}, \code{"hours"}
 #' @param alignPeriod positive integer, indicating the number of periods to aggregate
 #' over. For example, to aggregate an \code{xts} object to the 5-minute frequency, set
 #' \code{alignPeriod = 5} and \code{alignBy = "minutes"}.
@@ -264,9 +263,9 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #'
 #' Parameters:
 #' \itemize{
-#' \item \code{dailyvol} A string specifying the estimation method for the daily component \eqn{s_t}.
-#' Possible values are \code{"bipower", "rv", "medrv"}. \code{"bipower"} by default.
-#' \item \code{periodicvol} A string specifying the estimation method for the component of intraday volatility,
+#' \item \code{dailyVol} A string specifying the estimation method for the daily component \eqn{s_t}.
+#' Possible values are \code{"rBPCov", "rRVar", "rMedRVar"}. \code{"rBPCov"} by default.
+#' \item \code{periodicVol} A string specifying the estimation method for the component of intraday volatility,
 #' that depends in a deterministic way on the intraday time at which the return is observed.
 #' Possible values are \code{"SD", "WSD", "TML", "OLS"}. See Boudt et al. (2011) for details. Default = \code{"TML"}.
 #' \item \code{P1} A positive integer corresponding to the number of cosine terms used in the flexible Fourier
@@ -286,7 +285,7 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' 
 #' Let there be \eqn{T} days of \eqn{N} equally-spaced log-returns \eqn{r_{i,t}}, 
 #' \eqn{i = 1, \dots, N} and \eqn{i = 1, \dots, T}.
-#' In case of \code{method = "detper"}, the returns are modeled as
+#' In case of \code{method = "detPer"}, the returns are modeled as
 #' \deqn{
 #' r_{i,t} = f_i s_t u_{i,t}
 #' }
@@ -298,25 +297,25 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' and Andersen and Bollerslev (1997). The jump robust versions by Boudt et al.
 #' (2011) have also been implemented.
 #' 
-#' If \code{periodicvol = "SD"}, we have
+#' If \code{periodicVol = "SD"}, we have
 #' \deqn{
 #' \hat f_i^{SD} = \frac{SD_i}{\sqrt{\frac{1}{\lfloor{\lambda / \Delta}\rfloor} \sum_{j = 1}^N SD_j^2}}
 #' }
 #' with \eqn{\Delta = 1 / N}, cross-daily averages \eqn{SD_i = \sqrt{1/T \sum_{i = t}^T r_{i,t}^2}}, 
 #' and \eqn{\lambda} being the length of the intraday time intervals.
 #' 
-#' If \code{periodicvol = "WSD"}, we have another nonparametric estimator that is robust to jumps in contrast to
-#' \code{periodicvol = "SD"}. The definition of this estimator can be found in Boudt et al. (2011, Eqs. 2.9-2.12).
+#' If \code{periodicVol = "WSD"}, we have another nonparametric estimator that is robust to jumps in contrast to
+#' \code{periodicVol = "SD"}. The definition of this estimator can be found in Boudt et al. (2011, Eqs. 2.9-2.12).
 #' 
-#' The estimates when \code{periodicvol = "OLS"} and \code{periodicvol = "TML"} are based on the regression equation
+#' The estimates when \code{periodicVol = "OLS"} and \code{periodicVol = "TML"} are based on the regression equation
 #' \deqn{
 #' \log \left| 1/T \sum_{t = 1}^T r_{i,t} \right| - c = \log f_i + \varepsilon_i
 #' }
 #' with \emph{i.i.d.} zero-mean error term \eqn{\varepsilon_i} and \eqn{c = -0.63518}. 
-#' \code{periodicvol = "OLS"} employs ordinary-least-squares estimation and 
-#' \code{periodicvol = "TML"} truncated maximum-likelihood estimation (see Boudt et al., 2011, Section 2.2, for further details).
+#' \code{periodicVol = "OLS"} employs ordinary-least-squares estimation and 
+#' \code{periodicVol = "TML"} truncated maximum-likelihood estimation (see Boudt et al., 2011, Section 2.2, for further details).
 #' 
-#' \strong{Stochastic periodicity method (\code{"stochper"})}
+#' \strong{Stochastic periodicity method (\code{"stochPer"})}
 #' 
 #' Parameters:
 #' \itemize{
@@ -406,22 +405,22 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #'
 #' Parameters:
 #' \itemize{
-#' \item{\code{type}}{String specifying the type of kernel to be used. Options
+#' \item{\code{type}}{ String specifying the type of kernel to be used. Options
 #' include \code{"gaussian", "epanechnikov", "beta"}. Default = \code{"gaussian"}.}
-#' \item{\code{h}}{Scalar or vector specifying bandwidth(s) to be used in kernel.
+#' \item{\code{h}}{ Scalar or vector specifying bandwidth(s) to be used in kernel.
 #' If \code{h} is a scalar, it will be assumed equal throughout the sample. If
 #' it is a vector, it should contain bandwidths for each day. If left empty,
 #' it will be estimated. Default = \code{NULL}.}
-#' \item{\code{est}}{String specifying the bandwidth estimation method. Possible
+#' \item{\code{est}}{ String specifying the bandwidth estimation method. Possible
 #' values include \code{"cv", "quarticity"}. Method \code{"cv"} equals
 #' cross-validation, which chooses the bandwidth that minimizes the Integrated
 #' Square Error. \code{"quarticity"} multiplies the simple plug-in estimator
 #' by a factor based on the daily quarticity of the returns. \code{est} is
 #' obsolete if \code{h} has already been specified by the user.
 #' \code{"cv"} by default.}
-#' \item{\code{lower}}{Lower bound to be used in bandwidth optimization routine,
+#' \item{\code{lower}}{ Lower bound to be used in bandwidth optimization routine,
 #' when using cross-validation method. Default is \eqn{0.1n^{-0.2}}.}
-#' \item{\code{upper}}{Upper bound to be used in bandwidth optimization routine,
+#' \item{\code{upper}}{ Upper bound to be used in bandwidth optimization routine,
 #' when using cross-validation method. Default is \eqn{n^{-0.2}}.}
 #' }
 #'
@@ -473,9 +472,9 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' will be executed many times (roughly equal to the total number of
 #' observations), so it is advised to use a small value for \code{alpha}, to
 #' avoid a lot of false positives. Default = \code{0.005}.}
-#' \item{\code{volest} string specifying the realized volatility estimator to be
-#' used in local windows. Possible values are \code{"bipower", "rv", "medrv"}.
-#' Default = \code{"bipower"}.}
+#' \item{\code{volEst} string specifying the realized volatility estimator to be
+#' used in local windows. Possible values are \code{"rBPCov", "rRVar", "rMedRVar"}.
+#' Default = \code{"rBPCov"}.}
 #' \item{\code{online} boolean indicating whether estimations at a certain point
 #' \eqn{t} should be done online (using only information available at
 #' \eqn{t-1}), or ex post (using all observations between two change points).
@@ -551,8 +550,8 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' Parameters:
 #' \itemize{
 #' \item{\code{RM} string denoting which realized measure to use to estimate the local volatility. 
-#' Possible values are: \code{"bipower", "medrv", "minrv", "rv"}.
-#' Default = \code{"bipower"}}.
+#' Possible values are: \code{"rBPCov", "rMedRVar", "rMinRVar", "rCov", "rRVar"}.
+#' Default = \code{"rBPCov"}}.
 #' \item{\code{lookBackPeriod} positive integer denoting the amount of sub-sampled returns to use 
 #' for the estimation of the local volatility. Default is \code{10}.}
 #' \item{\code{dontIncludeLast} logical indicating whether to omit the last return in the calculation of the local volatility.
@@ -578,7 +577,7 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' Parameters:
 #' \itemize{
 #' \item{\code{RM} String denoting which realized measure to use to estimate the local volatility.
-#'  Possible values are: \code{"bipower", "medrv", "minrv", and "rv"}. Default = \code{"bipower"}}.
+#'  Possible values are: \code{"rBPCov", "rMedRVar", "rMinRVar", "rCov", and "rRVar"}. Default = \code{"rBPCov"}}.
 #' \item{\code{lookBackPeriod} positive integer denoting the amount of sub-sampled returns to use for the estimation of the local volatility. Default = 50.}
 #' }
 #' 
@@ -597,25 +596,24 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #'              delta_c = c(0.25, -0.05, -0.2, 0.13, 0.02),
 #'              delta_s = c(-1.2, 0.11, 0.26, -0.03, 0.08))
 #'
-#' # Next method will take around 360 iterations
-#' vol1 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)], method = "stochper", init = init)
-#' plot(as.numeric(vol1$spot[1:780]), type="l")
-#' legend("topright", c("stochper"), col = c("black"), lty=1)}
+#' # Next method will take around 370 iterations
+#' vol1 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)], method = "stochPer", init = init)
+#' plot(vol1$spot[1:780])
+#' legend("topright", c("stochPer"), col = c("black"), lty=1)}
 #'
 #' # Various kernel estimates
 #' \dontrun{
-#' h1 <- bw.nrd0((1:nrow(sampleOneMinuteData[, list(DT, PRICE = MARKET)]))*(5*60))
+#' h1 <- bw.nrd0((1:nrow(sampleOneMinuteData[, list(DT, PRICE = MARKET)]))*60)
 #' vol2 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)],
 #'                 method = "kernel", h = h1)
 #' vol3 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)], 
 #'                 method = "kernel", est = "quarticity")
 #' vol4 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)],
 #'                 method = "kernel", est = "cv")
-#' plot(vol2, length = 2880)
-#' lines(as.numeric(t(vol3$spot))[1:2880], col = "red")
-#' lines(as.numeric(t(vol4$spot))[1:2880], col = "blue")
-#' legend("topright", c("h = simple estimate", "h = quarticity corrected",
-#'                      "h = crossvalidated"), col = c("black", "red", "blue"), lty=1)}
+#' plot(cbind(vol2$spot, vol3$spot, vol4$spot))
+#' xts::addLegend("topright", c("h = simple estimate", "h = quarticity corrected",
+#'                      "h = crossvalidated"), col = 1:3, lty=1)
+#'}
 #'
 #' # Piecewise constant volatility
 #' \dontrun{
@@ -626,12 +624,21 @@ spotDrift <- function(data, method = "mean", alignBy = "minutes", alignPeriod =
 #' # Compare regular GARCH(1,1) model to eGARCH, both with external regressors
 #' \dontrun{
 #' vol6 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)], method = "garch", model = "sGARCH")
-#' vol7 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = STOCK)], method = "garch", model = "eGARCH")
+#' vol7 <- spotVol(sampleOneMinuteData[, list(DT, PRICE = MARKET)], method = "garch", model = "eGARCH")
 #' plot(as.numeric(t(vol6$spot)), type = "l")
 #' lines(as.numeric(t(vol7$spot)), col = "red")
 #' legend("topleft", c("GARCH", "eGARCH"), col = c("black", "red"), lty = 1)
 #' }
 #' 
+#' \dontrun{
+#' # Compare realized measure spot vol estimation to pre-averaged version
+#' vol8 <- spotVol(sampleTDataEurope[, list(DT, PRICE)], method = "RM", marketOpen = "09:00:00",
+#'                 marketClose = "17:30:00", tz = "UTC", alignPeriod = 1, alignBy = "mins",
+#'                 lookBackPeriod = 10)
+#' vol9 <- spotVol(sampleTDataEurope[, list(DT, PRICE)], method = "PARM", marketOpen = "09:00:00",
+#'                 marketClose = "17:30:00", tz = "UTC", lookBackPeriod = 10)
+#' plot(zoo::na.locf(cbind(vol8$spot, vol9$spot)))
+#' }
 #' @author Jonathan Cornelissen, Kris Boudt, Onno Kleen, and Emil Sjoerup.
 #'
 #' @references 
@@ -651,7 +658,14 @@ spotVol <- function(data, method = "detPer", alignBy = "minutes", alignPeriod =
                       marketOpen = "09:30:00", marketClose = "16:00:00",
                       tz = "GMT", ...) {
   
-  PRICE = DATE = RETURN = DT = NULL
+  DT <- PRICE <- DATE <- RETURN <- NULL
+  
+  validOptions <- c("detPer", "stochPer", "kernel", "piecewise", "garch", "RM", "PARM")
+  method <- method[1]
+  if(!(method %in% validOptions)){
+    stop(c("method not a valid option, valid options are: ", paste(validOptions, collapse = ", ")))
+  }
+  
   
   if (!("PRICE" %in% colnames(data))) {
     if (dim(data)[2] == 1) {
@@ -671,19 +685,23 @@ spotVol <- function(data, method = "detPer", alignBy = "minutes", alignPeriod =
       stop("Input has to be data.table or xts.")
     }
   } else {
+    data <- copy(data)
     if (!("DT" %in% colnames(data))) {
       stop("Data.table needs DT column containing the time-stamps of the trades.") # added the timestamp comment for verbosity.
     }
   }
   
   if( method != "PARM"){
-    
-    datad <- aggregatePrice(data[, DATE := ""], alignBy = alignBy, alignPeriod = alignPeriod , marketOpen = marketOpen,
-                            marketClose = marketClose, tz = tz, fill = TRUE) # The allocation of date let's aggregatePrice return the date so we don't have to calculate it multiple times.
+    if(!is.null(alignPeriod) && !is.null(alignBy)){
+      datad <- aggregatePrice(data, alignBy = alignBy, alignPeriod = alignPeriod , marketOpen = marketOpen,
+                              marketClose = marketClose, tz = tz, fill = TRUE) # The allocation of date let's aggregatePrice return the date so we don't have to calculate it multiple times.
+    } else {
+      datad <- copy(data)
+    }
     setkeyv(datad, "DT")
-    datad <- datad[, RETURN := log(PRICE) - shift(log(PRICE), type = "lag"), by = "DATE"][!is.na(RETURN)]
+    datad <- datad[, RETURN := log(PRICE) - shift(log(PRICE), type = "lag"), by = list(DATE = as.Date(DT))][!is.na(RETURN)]
     rData <- xts(datad$RETURN, order.by = datad$DT)
-    datad <- split(datad, by = "DATE")
+    datad <- split(datad[, DATE := as.Date(DT)], by = "DATE")
     mR <- matrix(unlist(lapply(datad, FUN = function(x) as.numeric(x$RETURN))), ncol = length(datad[[1]]$RETURN), byrow = TRUE)
     
     if (method == "kernel") {
@@ -698,7 +716,7 @@ spotVol <- function(data, method = "detPer", alignBy = "minutes", alignPeriod =
   options <- list(...)
   out <- switch(method,
                 detPer = detPer(mR, rData = rData, options = options),
-                stochper = stochPer(mR, rData = rData, options = options),
+                stochPer = stochPer(mR, rData = rData, options = options),
                 kernel = kernelestim(mR, rData = rData, delta, options = options),
                 piecewise = piecewise(mR, rData = rData, options = options),
                 garch = garch_s(mR, rData = rData, options = options),
